@@ -1489,16 +1489,16 @@ class EntryControllerTest extends WallabagCoreTestCase
                 'it',
             ],
             'zh_CN' => [
-                'http://www.hao123.com/shequ?__noscript__-=1',
+                'http://tuijian.hao123.com/tuijian/?__noscript__-=1',
                 'zh_CN',
             ],
             'pt_BR' => [
-                'https://politica.estadao.com.br/noticias/eleicoes,campanha-catatonica,70002491983',
+                'https://esportes.r7.com/lance/futebol/victor-hugo-e-matheus-franca-devem-desfalcar-flamengo-no-carioca-22112022',
                 'pt_BR',
             ],
             'es-ES' => [
-                'https://www.20minutos.es/noticia/3360685/0/gobierno-sanchez-primero-historia-mas-mujeres-que-hombres/',
-                'es_ES',
+                'https://elpais.com/internacional/2022-11-03/ultima-hora-de-la-guerra-entre-rusia-y-ucrania-hoy-en-directo.html',
+                'es',
             ],
         ];
     }
